Index: trunk/MagicSoft/Mars/mhft/MGeomCamMagicEnhance.h
===================================================================
--- trunk/MagicSoft/Mars/mhft/MGeomCamMagicEnhance.h	(revision 6855)
+++ trunk/MagicSoft/Mars/mhft/MGeomCamMagicEnhance.h	(revision 6857)
@@ -7,17 +7,17 @@
 
 class MArrayD;
-class MCerPhotEvt;
+class MSignalCam;
 
 class MGeomCamMagicEnhance : public MTask
 {
 private:
-    static const char *fgNameCerPhotEvtIn;
-    static const char *fgNameCerPhotEvtOut;
+    static const char *fgNameSignalCamIn;
+    static const char *fgNameSignalCamOut;
 
-    TString fNameCerPhotEvtIn;
-    TString fNameCerPhotEvtOut;
+    TString fNameSignalCamIn;
+    TString fNameSignalCamOut;
 
-    MCerPhotEvt *fEvtIn;
-    MCerPhotEvt *fEvtOut;
+    MSignalCam *fEvtIn;
+    MSignalCam *fEvtOut;
 
     MArrayD Convert() const;
@@ -31,8 +31,8 @@
     MGeomCamMagicEnhance(const char *name=0, const char *title=0);
 
-    void SetNameCerPhotEvtIn(const char *n) { fNameCerPhotEvtIn = n; }
-    void SetNameCerPhotEvtOut(const char *n) { fNameCerPhotEvtOut = n; }
+    void SetNameSignalCamIn(const char *n) { fNameSignalCamIn = n; }
+    void SetNameSignalCamOut(const char *n) { fNameSignalCamOut = n; }
 
-    ClassDef(MGeomCamMagicEnhance, 0) //Task to convert MCerPhotEvt from MGeomCamMagic to MGeomCamMagicXT
+    ClassDef(MGeomCamMagicEnhance, 0) //Task to convert MSignalCam from MGeomCamMagic to MGeomCamMagicXT
 };
     
Index: trunk/MagicSoft/Mars/mhft/Makefile
===================================================================
--- trunk/MagicSoft/Mars/mhft/Makefile	(revision 6855)
+++ trunk/MagicSoft/Mars/mhft/Makefile	(revision 6857)
@@ -19,5 +19,5 @@
 #  connect the include files defined in the config.mk file
 #
-INCLUDES = -I. -I../mbase -I../mgui -I../mgeom -I../manalysis
+INCLUDES = -I. -I../mbase -I../mgui -I../mgeom -I../msignal
 
 #manalysis: MChisqEval (MParameters)

Index: trunk/MagicSoft/Mars/mhft/MGeomCamMagicEnhance.cc
===================================================================
--- trunk/MagicSoft/Mars/mhft/MGeomCamMagicEnhance.cc	(revision 6855)
+++ trunk/MagicSoft/Mars/mhft/MGeomCamMagicEnhance.cc	(revision 6857)
@@ -28,6 +28,6 @@
 // MGeomCamMagicEnhance
 //
 // This task takes MCerPhotEvt assuming that it is related to the Magic
 // camera geometry. By deviding and interpolation it resamples MCerPhotEvt
 // such, that afterwards it is related to a geometry MGeomCamMagicXT
 //
@@ -40,6 +40,6 @@
 #include "MParList.h"
 
-#include "MCerPhotEvt.h"
-#include "MCerPhotPix.h"
+#include "MSignalCam.h"
+#include "MSignalPix.h"
 
 #include "MArrayD.h"
@@ -49,6 +49,6 @@
 using namespace std;
 
-const char *MGeomCamMagicEnhance::fgNameCerPhotEvtIn  = "MCerPhotEvt";
-const char *MGeomCamMagicEnhance::fgNameCerPhotEvtOut = "MCerPhotEvt";
+const char *MGeomCamMagicEnhance::fgNameSignalCamIn  = "MSignalCam";
+const char *MGeomCamMagicEnhance::fgNameSignalCamOut = "MSignalCam";
 
 // ---------------------------------------------------------------------------
@@ -57,25 +57,25 @@
 //
 MGeomCamMagicEnhance::MGeomCamMagicEnhance(const char *name, const char *title)
-    : fNameCerPhotEvtIn(fgNameCerPhotEvtIn), fNameCerPhotEvtOut(fgNameCerPhotEvtOut),
+    : fNameSignalCamIn(fgNameSignalCamIn), fNameSignalCamOut(fgNameSignalCamOut),
     fEvtIn(0), fEvtOut(0)
 {
     fName  = name  ? name  : "MGeomCamMagicEnhance";
-    fTitle = title ? title : "Task to convert MCerPhotEvt from MGeomCamMagic to MGeomCamMagicXT";
+    fTitle = title ? title : "Task to convert MSignalCam from MGeomCamMagic to MGeomCamMagicXT";
 }
 
 // ---------------------------------------------------------------------------
 //
 //  Search for MCerPhotEvt input and output container.
 //
 Int_t MGeomCamMagicEnhance::PreProcess(MParList *plist)
 {
-    fEvtIn = (MCerPhotEvt*)plist->FindObject(fNameCerPhotEvtIn, "MCerPhotEvt");
+    fEvtIn = (MSignalCam*)plist->FindObject(fNameSignalCamIn, "MSignalCam");
     if (!fEvtIn)
     {
-        *fLog << err << fNameCerPhotEvtIn << " [MCerPhotEvt] not found... abort." << endl;
+        *fLog << err << fNameSignalCamIn << " [MSignalCam] not found... abort." << endl;
         return kFALSE;
     }
 
-    fEvtOut = (MCerPhotEvt*)plist->FindCreateObj("MCerPhotEvt", fNameCerPhotEvtOut);
+    fEvtOut = (MSignalCam*)plist->FindCreateObj("MSignalCam", fNameSignalCamOut);
     if (!fEvtOut)
         return kFALSE;
@@ -155,5 +155,5 @@
 // ---------------------------------------------------------------------------
 //
 //  Call Convert and copy result into output MCerPhotEvt
 //
 Int_t MGeomCamMagicEnhance::Process()
@@ -162,5 +162,5 @@
     const MArrayD res(Convert());
 
-    // Copy result into output MCerPhotEvt
+    // Copy result into output MSignalCam
     fEvtOut->InitSize(res.GetSize());
 
@@ -28,6 +28,6 @@
 // MGeomCamMagicEnhance
 //
-// This task takes MCerPhotEvt assuming that it is related to the Magic
-// camera geometry. By deviding and interpolation it resamples MCerPhotEvt
+// This task takes MSignalCam assuming that it is related to the Magic
+// camera geometry. By deviding and interpolation it resamples MSignalCam
 // such, that afterwards it is related to a geometry MGeomCamMagicXT
 //
@@ -57,25 +57,25 @@
 // ---------------------------------------------------------------------------
 //
-//  Search for MCerPhotEvt input and output container.
+//  Search for MSignalCam input and output container.
 //
 Int_t MGeomCamMagicEnhance::PreProcess(MParList *plist)
@@ -155,5 +155,5 @@
 // ---------------------------------------------------------------------------
 //
-//  Call Convert and copy result into output MCerPhotEvt
+//  Call Convert and copy result into output MSignalCam
 //
 Int_t MGeomCamMagicEnhance::Process()
Index: trunk/MagicSoft/Mars/mhft/MHexagonalFTCalc.cc
===================================================================
--- trunk/MagicSoft/Mars/mhft/MHexagonalFTCalc.cc	(revision 6855)
+++ trunk/MagicSoft/Mars/mhft/MHexagonalFTCalc.cc	(revision 6857)
@@ -31,6 +31,6 @@
 // backward tranformation.
 //
 // If you don't want to copy the rsult back to any MCerPhotEvt call
 // SetNameCerPhotEvtOut()
 //
 // Currently - this will change in the future! - there are two output
@@ -60,6 +60,6 @@
 #include "MGeomPix.h"
 
-#include "MCerPhotEvt.h"
-#include "MCerPhotPix.h"
+#include "MSignalCam.h"
+#include "MSignalPix.h"
 
 #include "MHexagonFreqSpace.h"
@@ -72,6 +72,6 @@
 
 const char *MHexagonalFTCalc::fgNameGeomCam       = "MGeomCam";
-const char *MHexagonalFTCalc::fgNameCerPhotEvtIn  = "MCerPhotEvt";
-const char *MHexagonalFTCalc::fgNameCerPhotEvtOut = "MCerPhotEvt";
+const char *MHexagonalFTCalc::fgNameSignalCamIn  = "MSignalCam";
+const char *MHexagonalFTCalc::fgNameSignalCamOut = "MSignalCam";
 
 // ---------------------------------------------------------------------------
@@ -83,5 +83,5 @@
 MHexagonalFTCalc::MHexagonalFTCalc(const char *name, const char *title)
     : fNameGeomCam(fgNameGeomCam),
-    fNameCerPhotEvtIn(fgNameCerPhotEvtIn), fNameCerPhotEvtOut(fgNameCerPhotEvtOut),
+    fNameSignalCamIn(fgNameSignalCamIn), fNameSignalCamOut(fgNameSignalCamOut),
     fEvtIn(0), fEvtOut(0), 
     fMaxAmplitude(0.08), fMaxRowFraction(0.75), fSkipBwdTrafo(kFALSE)
@@ -114,15 +114,15 @@
 Int_t MHexagonalFTCalc::PreProcess(MParList *plist)
 {
-    fEvtIn = (MCerPhotEvt*)plist->FindObject(fNameCerPhotEvtIn, "MCerPhotEvt");
+    fEvtIn = (MSignalCam*)plist->FindObject(fNameSignalCamIn, "MSignalCam");
     if (!fEvtIn)
     {
-        *fLog << err << fNameCerPhotEvtIn << " [MCerPhotEvt] not found... abort." << endl;
+        *fLog << err << fNameSignalCamIn << " [MSignalCam] not found... abort." << endl;
         return kFALSE;
     }
 
     fEvtOut=0;
-    if (!fNameCerPhotEvtOut.IsNull())
-    {
-        fEvtOut = (MCerPhotEvt*)plist->FindCreateObj(fNameCerPhotEvtOut, "MCerPhotEvt");
+    if (!fNameSignalCamOut.IsNull())
+    {
+        fEvtOut = (MSignalCam*)plist->FindCreateObj(fNameSignalCamOut, "MSignalCam");
         if (!fEvtOut)
             return kFALSE;
@@ -240,5 +240,5 @@
 // ---------------------------------------------------------------------------
 //
 // - Copy input MCerPhotEvt using the pixel mapping into an array
 // - Do forward transformation
 // - substract fourier offset
@@ -246,5 +246,5 @@
 // - add fourier offset
 // - do backward tranformation
 // - copy result back into output MCerPhotEvt
 //
 Int_t MHexagonalFTCalc::Process()
@@ -254,8 +254,8 @@
     MArrayD re(lim);
 
     //    MCerPhotPix *pix=0;
     //    MCerPhotEvtIter Next(fEvtIn, kFALSE);
     //    while ((pix = (MCerPhotPix*)Next()))
     // Copy data from MCerPhotEvt into array
     const UInt_t npix = fEvtIn->GetNumPixels();
     for (UInt_t idx=0; idx<npix; idx++)
@@ -302,5 +302,5 @@
 
     // ----------------------------------------------------
-    // Do we have to copy the result back into MCerPhotEvt?
+    // Do we have to copy the result back into MSignalCam?
     // ----------------------------------------------------
     if (!fEvtOut)
@@ -31,6 +31,6 @@
 // backward tranformation.
 //
-// If you don't want to copy the rsult back to any MCerPhotEvt call
-// SetNameCerPhotEvtOut()
+// If you don't want to copy the rsult back to any MSignalCam call
+// SetNameSignalCamOut()
 //
 // Currently - this will change in the future! - there are two output
@@ -240,5 +240,5 @@
 // ---------------------------------------------------------------------------
 //
-// - Copy input MCerPhotEvt using the pixel mapping into an array
+// - Copy input MSignalCam using the pixel mapping into an array
 // - Do forward transformation
 // - substract fourier offset
@@ -246,5 +246,5 @@
 // - add fourier offset
 // - do backward tranformation
-// - copy result back into output MCerPhotEvt
+// - copy result back into output MSignalCam
 //
 Int_t MHexagonalFTCalc::Process()
@@ -254,8 +254,8 @@
     MArrayD re(lim);
 
-    //    MCerPhotPix *pix=0;
-    //    MCerPhotEvtIter Next(fEvtIn, kFALSE);
-    //    while ((pix = (MCerPhotPix*)Next()))
-    // Copy data from MCerPhotEvt into array
+    //    MSignalPix *pix=0;
+    //    MSignalCamIter Next(fEvtIn, kFALSE);
+    //    while ((pix = (MSignalPix*)Next()))
+    // Copy data from MSignalCam into array
     const UInt_t npix = fEvtIn->GetNumPixels();
     for (UInt_t idx=0; idx<npix; idx++)
Index: trunk/MagicSoft/Mars/mhft/MHexagonalFTCalc.h
===================================================================
--- trunk/MagicSoft/Mars/mhft/MHexagonalFTCalc.h	(revision 6855)
+++ trunk/MagicSoft/Mars/mhft/MHexagonalFTCalc.h	(revision 6857)
@@ -13,5 +13,5 @@
 
 class MArrayD;
-class MCerPhotEvt;
+class MSignalCam;
 class MHexagonFreqSpace;
 
@@ -20,13 +20,13 @@
 private:
     static const char *fgNameGeomCam;       // Default name of used geometry
-    static const char *fgNameCerPhotEvtIn;  // Default name of used input MCerPhotEvt
-    static const char *fgNameCerPhotEvtOut; // Default name of used output MCerPhotEvt
+    static const char *fgNameSignalCamIn;  // Default name of used input MSignalCam
+    static const char *fgNameSignalCamOut; // Default name of used output MSignalCam
 
     TString fNameGeomCam;       // name of used geometry
-    TString fNameCerPhotEvtIn;  // name of used input MCerPhotEvt
-    TString fNameCerPhotEvtOut; // name of used output MCerPhotEvt
+    TString fNameSignalCamIn;  // name of used input MSignalCam
+    TString fNameSignalCamOut; // name of used output MSignalCam
 
-    MCerPhotEvt       *fEvtIn;  // input MCerPhotEvt
-    MCerPhotEvt       *fEvtOut; // output MCerPhotEvt
+    MSignalCam       *fEvtIn;  // input MSignalCam
+    MSignalCam       *fEvtOut; // output MSignalCam
 
     MHexagonFreqSpace *fFreq1;  //!
@@ -56,6 +56,6 @@
 
     void SetNameGeomCam(const char *n) { fNameGeomCam = n; }       // name of camera geometry used 
-    void SetNameCerPhotEvtIn(const char *n)     { fNameCerPhotEvtIn = n; }  // name of input MCerPhotEvt used
-    void SetNameCerPhotEvtOut(const char *n="") { fNameCerPhotEvtOut = n; } // name of ouput MCerPhotEvt used
+    void SetNameSignalCamIn(const char *n)     { fNameSignalCamIn = n; }  // name of input MSignalCam used
+    void SetNameSignalCamOut(const char *n="") { fNameSignalCamOut = n; } // name of ouput MSignalCam used
 
     void SetMaxAmplitude(Float_t max) { fMaxAmplitude=max; } // amplitude to cut at